aboutsummaryrefslogtreecommitdiffstats
path: root/python_openapi_client/fatcat_openapi_client/models/auth_oidc.py
diff options
context:
space:
mode:
Diffstat (limited to 'python_openapi_client/fatcat_openapi_client/models/auth_oidc.py')
-rw-r--r--python_openapi_client/fatcat_openapi_client/models/auth_oidc.py15
1 files changed, 8 insertions, 7 deletions
diff --git a/python_openapi_client/fatcat_openapi_client/models/auth_oidc.py b/python_openapi_client/fatcat_openapi_client/models/auth_oidc.py
index 4fbad558..7b1da81b 100644
--- a/python_openapi_client/fatcat_openapi_client/models/auth_oidc.py
+++ b/python_openapi_client/fatcat_openapi_client/models/auth_oidc.py
@@ -5,9 +5,9 @@
Fatcat is a scalable, versioned, API-oriented catalog of bibliographic entities and file metadata. # noqa: E501
- OpenAPI spec version: 0.3.1
+ The version of the OpenAPI document: 0.3.1
Contact: webservices@archive.org
- Generated by: https://github.com/swagger-api/swagger-codegen.git
+ Generated by: https://openapi-generator.tech
"""
@@ -18,19 +18,20 @@ import six
class AuthOidc(object):
- """NOTE: This class is auto generated by the swagger code generator program.
+ """NOTE: This class is auto generated by OpenAPI Generator.
+ Ref: https://openapi-generator.tech
Do not edit the class manually.
"""
"""
Attributes:
swagger_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name
and the value is json key in definition.
"""
- swagger_types = {
+ openapi_types = {
'provider': 'str',
'sub': 'str',
'iss': 'str',
@@ -45,7 +46,7 @@ class AuthOidc(object):
}
def __init__(self, provider=None, sub=None, iss=None, preferred_username=None): # noqa: E501
- """AuthOidc - a model defined in Swagger""" # noqa: E501
+ """AuthOidc - a model defined in OpenAPI""" # noqa: E501
self._provider = None
self._sub = None
@@ -162,7 +163,7 @@ class AuthOidc(object):
"""Returns the model properties as a dict"""
result = {}
- for attr, _ in six.iteritems(self.swagger_types):
+ for attr, _ in six.iteritems(self.openapi_types):
value = getattr(self, attr)
if isinstance(value, list):
result[attr] = list(map(
@@ -18,19 +18,20 @@ import six
"""
Attributes:
- swagger_types (dict): The key is attribute name
+ openapi_types (dict): The key is attribute name
and the value is attribute type.
attribute_map (dict): The key is attribute name